@@ -34,8 +34,8 @@ def fetch_data(sql_query):
 def fetch_data_sso(sql_query, email):
     """ fetch data from snowflake tables using SSO auth """
     ctx = snowflake.connector.connect(
-        user=email,
-        account=os.environ['SK_PASSWORD'],
+        user=email.upper(),
+        account=os.environ['SK_ACCOUNT'],
         authenticator='externalbrowser',
         warehouse=os.environ['SK_WAREHOUSE']
     )
